#-------------------------------------------------------------------------------
# Клиент redis для записи калибровочных данных в EEPROM устройств
# OldBean, 19.02.2019
#-------------------------------------------------------------------------------
import tkinter as tk # Библиотека для создания GUI
from tkinter import ttk  
import redis # Для работы с СУБД redis

r = redis.StrictRedis() # Соединяемся с базой данных
devlst = [] # Список ключей и устройств с калибровками
keys = sorted(r.keys('ix*'))
dikeys = []
for key in keys: # Пробегаем по списку ключей
  fc = int(r.hget(key, b'fc')) # Код семейства устройства с данным ключем
  if fc in [0xA1, 0xA3, 0xA4, 0xA6, 0xA7]:
    devlst.append(key.decode()[1:] + ' - ' + r.hget(b'codes', fc).decode())
    dikeys.append(key)
units = [x.decode() for x in r.lrange(b'units', 0, -1)]

root = tk.Tk() # Основное окно
root.wm_title('calibr') # Заголовок
root.resizable(width = False, height = False) # Фиксированные размеры окна

ikey = None # Ключ выбранного устройства
def seldev(event): # Вызывается при выборе устройства (модуля)
  global ikey, coef, offset, ui
  ikey = ('i' + cbdev.get().split()[0]).encode() # Ключ устройства в БД
  vcoef.set(float(r.hget(ikey, b'coef')))
  voffset.set(int(r.hget(ikey, b'offset')))
  ui = int(r.hget(ikey, b'ui'))
  if ui < 0 or ui >= len(units): # Некорректные значения индекса
    ui = 0
  vunit.set(units[ui])

# Выпадающий список для выбора устройства
tk.Label(root, text = 'Device:', anchor = 'w').grid(column = 0,row = 0, sticky = tk.W)
cbdev= ttk.Combobox(width = 24, values = devlst, justify = tk.RIGHT)
cbdev .grid(column = 1,row = 0, sticky = tk.W)
cbdev.bind('<<ComboboxSelected>>', seldev)
# Поля (метка и редактируемое поле) для коэффициента
vcoef = tk.DoubleVar()
tk.Label(root, text='coef', anchor = 'w').grid(column = 0,row = 1, sticky = tk.W)
ecoef = tk.Entry(root, width = 24, textvariable = vcoef, justify = tk.RIGHT)
ecoef.grid(column = 1,row = 1, sticky = tk.W)
# Поля для установки смещения
voffset = tk.IntVar()
tk.Label(root, text='offset', anchor = 'w').grid(column = 0,row = 2, sticky = tk.W)
eoffset = tk.Entry(root, width = 24, textvariable = voffset, justify = tk.RIGHT)
eoffset.grid(column = 1,row = 2, sticky = tk.W)
# Выпадающий список для установки единицы измерения
tk.Label(root, text = 'Unit:').grid(column = 0,row = 3, sticky = tk.W)
vunit = tk.StringVar()
cbunit= ttk.Combobox(width = 24, textvariable = vunit, values = units, 
                     justify = tk.RIGHT)
cbunit.grid(column = 1,row = 3, sticky = tk.W)

def updateeeprom(): # Запись калибровочный данных в EEPROM
  r.hset(ikey, b'coef', vcoef.get()) # Заносим данные в хэш данного устройства
  r.hset(ikey, b'offset', voffset.get())
  r.hset(ikey, b'ui', units.index(vunit.get()))
  r.rpush(b'mucal', ikey[1:]) # Добавляем устройство в очередь для обновления EEPROM
# Кнопка записи калибровочных данных в EEPROM
tk.Button(root, text = 'Update EEPROM', command = updateeeprom).grid(column = 0,
          row = 4, columnspan = 2)
root.mainloop()
#-------------------------------------------------------------------------------
